==> cl_appbase-0.0.46.tar.gz: lib/src/api/data_hub/hub_resource.dart <==
import 'package:cl_appbase/api.dart';
import 'package:cl_appbase/appbase.dart';
import 'package:boost/boost.dart';

import '../api.dart';
import '../api_resource.dart';

class ListHubResource<TData extends TransferObject, TId>
    extends ListApiResource<TData, TId>
    implements ParameterizedCollection<TData> {
  const ListHubResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super(api, endpointSuffix, factory);

  Future<TData> getMetaData<TData>(String key,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await request<Map<String, dynamic>, Map<String, dynamic>>(
        api.baseUrl, endpointSuffix, params, ApiRequestMethod.GET,
        headers: api.getRequestHeaders(),
        query: {'\$$key': null, if (query != null) ...query});
    response.throwOnError();
    return response.data[key] as TData;
  }

  /// Implements ParameterizedCollection.getItems
  @override
  Future<List<TData>> getItems(int offset, int limit,
          {Map<String, dynamic>? params, Map<String, String?>? query}) async =>
      await getList(offset, limit, params: params, query: query);

  /// Implements ParameterizedCollection.getSize
  @override
  Future<int> getSize(
          {Map<String, dynamic>? params, Map<String, String?>? query}) async =>
      await getMetaData('count', params: params, query: query);
}

class SingleObjectHubResource<TData extends TransferObject>
    extends SingleObjectApiResource<TData> {
  SingleObjectHubResource(
      ApiBase api, String endpointSuffix, DTOFactory<TData> factory)
      : super(api, endpointSuffix, factory);

  Future<TData> getMetaData<TData>(String key) async {
    final response = await request<Map<String, dynamic>, Map<String, dynamic>>(
        api.baseUrl, '$endpointSuffix?\$$key', null, ApiRequestMethod.GET,
        headers: api.getRequestHeaders());
    response.throwOnError();
    return response.data[key] as TData;
  }
}

==> cl_appbase-0.2.3.tar.gz: lib/src/api/data_hub/hub_resource.dart <==
import 'package:cl_appbase/appbase.dart';

import '../api.dart';

class ListHubResource<TData, TId> extends ListApiResource<TData, TId>
    implements ParameterizedCollection<TData> {
  const ListHubResource(
      ApiBase api, String endpointSuffix, TransferBean<TData> bean)
      : super(api, endpointSuffix, bean);

  Future<TData> getMetaData<TData>(String key,
      {Map<String, dynamic>? params, Map<String, String?>? query}) async {
    final response = await request<Map<String, dynamic>, Map<String, dynamic>>(
        api.baseUrl, endpointSuffix, params, ApiRequestMethod.GET,
        headers: api.getRequestHeaders(),
        query: {'\$$key': null, if (query != null) ...query});
    response.throwOnError();
    return response.data[key] as TData;
  }

  /// Implements ParameterizedCollection.getItems
  @override
  Future<List<TData>> getItems(int offset, int limit,
          {Map<String, dynamic>? params, Map<String, String?>? query}) async =>
      await getList(offset, limit, params: params, query: query);

  /// Implements ParameterizedCollection.getSize
  @override
  Future<int> getSize(
          {Map<String, dynamic>? params, Map<String, String?>? query}) async =>
      await getMetaData('count', params: params, query: query);
}

class SingleObjectHubResource<TData extends TransferObject>
    extends SingleObjectApiResource<TData> {
  SingleObjectHubResource(
      ApiBase api, String endpointSuffix, TransferBean<TData> bean)
      : super(api, endpointSuffix, bean);

  Future<TData> getMetaData<TData>(String key) async {
    final response = await request<Map<String, dynamic>, Map<String, dynamic>>(
        api.baseUrl, '$endpointSuffix?\$$key', null, ApiRequestMethod.GET,
        headers: api.getRequestHeaders());
    response.throwOnError();
    return response.data[key] as TData;
  }
}
